#[repr(transparent)]pub struct Esr1(pub u32);Expand description
Error and Status 1 Register
Tuple Fields
0: u32Implementations
Sourceimpl Esr1
impl Esr1
Sourcepub const fn set_wakint(&mut self, val: bool)
pub const fn set_wakint(&mut self, val: bool)
Wake-Up Interrupt
Sourcepub const fn set_errint(&mut self, val: bool)
pub const fn set_errint(&mut self, val: bool)
Error Interrupt
Sourcepub const fn set_boffint(&mut self, val: bool)
pub const fn set_boffint(&mut self, val: bool)
Bus Off Interrupt
Sourcepub const fn set_fltconf(&mut self, val: Fltconf)
pub const fn set_fltconf(&mut self, val: Fltconf)
Fault Confinement State
Sourcepub const fn set_stferr(&mut self, val: Stferr)
pub const fn set_stferr(&mut self, val: Stferr)
Stuffing Error
Sourcepub const fn set_frmerr(&mut self, val: Frmerr)
pub const fn set_frmerr(&mut self, val: Frmerr)
Form Error
Sourcepub const fn set_crcerr(&mut self, val: Crcerr)
pub const fn set_crcerr(&mut self, val: Crcerr)
Cyclic Redundancy Check Error
Sourcepub const fn set_ackerr(&mut self, val: Ackerr)
pub const fn set_ackerr(&mut self, val: Ackerr)
Acknowledge Error
Sourcepub const fn set_bit0err(&mut self, val: Bit0err)
pub const fn set_bit0err(&mut self, val: Bit0err)
Bit0 Error
Sourcepub const fn set_bit1err(&mut self, val: Bit1err)
pub const fn set_bit1err(&mut self, val: Bit1err)
Bit1 Error
Sourcepub const fn set_rwrnint(&mut self, val: Rwrnint)
pub const fn set_rwrnint(&mut self, val: Rwrnint)
Rx Warning Interrupt Flag
Sourcepub const fn set_twrnint(&mut self, val: Twrnint)
pub const fn set_twrnint(&mut self, val: Twrnint)
Tx Warning Interrupt Flag
Sourcepub const fn boffdoneint(&self) -> Boffdoneint
pub const fn boffdoneint(&self) -> Boffdoneint
Bus Off Done Interrupt
Sourcepub const fn set_boffdoneint(&mut self, val: Boffdoneint)
pub const fn set_boffdoneint(&mut self, val: Boffdoneint)
Bus Off Done Interrupt
Sourcepub const fn errint_fast(&self) -> ErrintFast
pub const fn errint_fast(&self) -> ErrintFast
Error interrupt for errors detected in Data Phase of CAN FD frames with BRS bit set
Sourcepub const fn set_errint_fast(&mut self, val: ErrintFast)
pub const fn set_errint_fast(&mut self, val: ErrintFast)
Error interrupt for errors detected in Data Phase of CAN FD frames with BRS bit set
Sourcepub const fn set_errovr(&mut self, val: Errovr)
pub const fn set_errovr(&mut self, val: Errovr)
Error Overrun
Sourcepub const fn stferr_fast(&self) -> StferrFast
pub const fn stferr_fast(&self) -> StferrFast
Stuffing Error in the Data Phase of CAN FD frames with the BRS bit set
Sourcepub const fn set_stferr_fast(&mut self, val: StferrFast)
pub const fn set_stferr_fast(&mut self, val: StferrFast)
Stuffing Error in the Data Phase of CAN FD frames with the BRS bit set
Sourcepub const fn frmerr_fast(&self) -> FrmerrFast
pub const fn frmerr_fast(&self) -> FrmerrFast
Form Error in the Data Phase of CAN FD frames with the BRS bit set
Sourcepub const fn set_frmerr_fast(&mut self, val: FrmerrFast)
pub const fn set_frmerr_fast(&mut self, val: FrmerrFast)
Form Error in the Data Phase of CAN FD frames with the BRS bit set
Sourcepub const fn crcerr_fast(&self) -> CrcerrFast
pub const fn crcerr_fast(&self) -> CrcerrFast
Cyclic Redundancy Check Error in the CRC field of CAN FD frames with the BRS bit set
Sourcepub const fn set_crcerr_fast(&mut self, val: CrcerrFast)
pub const fn set_crcerr_fast(&mut self, val: CrcerrFast)
Cyclic Redundancy Check Error in the CRC field of CAN FD frames with the BRS bit set
Sourcepub const fn bit0err_fast(&self) -> Bit0errFast
pub const fn bit0err_fast(&self) -> Bit0errFast
Bit0 Error in the Data Phase of CAN FD frames with the BRS bit set
Sourcepub const fn set_bit0err_fast(&mut self, val: Bit0errFast)
pub const fn set_bit0err_fast(&mut self, val: Bit0errFast)
Bit0 Error in the Data Phase of CAN FD frames with the BRS bit set
Sourcepub const fn bit1err_fast(&self) -> Bit1errFast
pub const fn bit1err_fast(&self) -> Bit1errFast
Bit1 Error in the Data Phase of CAN FD frames with the BRS bit set
Sourcepub const fn set_bit1err_fast(&mut self, val: Bit1errFast)
pub const fn set_bit1err_fast(&mut self, val: Bit1errFast)
Bit1 Error in the Data Phase of CAN FD frames with the BRS bit set