#[repr(transparent)]pub struct Mb458bCs(pub u32);Expand description
Message Buffer 45 CS Register
Tuple Fields
0: u32Implementations
Sourceimpl Mb458bCs
impl Mb458bCs
Sourcepub const fn time_stamp(&self) -> u16
pub const fn time_stamp(&self) -> u16
Free-Running Counter Time stamp. This 16-bit field is a copy of the Free-Running Timer, captured for Tx and Rx frames at the time when the beginning of the Identifier field appears on the CAN bus.
Sourcepub const fn set_time_stamp(&mut self, val: u16)
pub const fn set_time_stamp(&mut self, val: u16)
Free-Running Counter Time stamp. This 16-bit field is a copy of the Free-Running Timer, captured for Tx and Rx frames at the time when the beginning of the Identifier field appears on the CAN bus.
Sourcepub const fn set_rtr(&mut self, val: bool)
pub const fn set_rtr(&mut self, val: bool)
Remote Transmission Request. One/zero for remote/data frame.
Sourcepub const fn set_ide(&mut self, val: bool)
pub const fn set_ide(&mut self, val: bool)
ID Extended. One/zero for extended/standard format frame.
Sourcepub const fn set_srr(&mut self, val: bool)
pub const fn set_srr(&mut self, val: bool)
Substitute Remote Request. Contains a fixed recessive bit.
Sourcepub const fn code(&self) -> u8
pub const fn code(&self) -> u8
Message Buffer Code. This 4-bit field can be accessed (read or write) by the CPU and by the FlexCAN module itself, as part of the message buffer matching and arbitration process.
Sourcepub const fn set_code(&mut self, val: u8)
pub const fn set_code(&mut self, val: u8)
Message Buffer Code. This 4-bit field can be accessed (read or write) by the CPU and by the FlexCAN module itself, as part of the message buffer matching and arbitration process.
Sourcepub const fn esi(&self) -> bool
pub const fn esi(&self) -> bool
Error State Indicator. This bit indicates if the transmitting node is error active or error passive.
Sourcepub const fn set_esi(&mut self, val: bool)
pub const fn set_esi(&mut self, val: bool)
Error State Indicator. This bit indicates if the transmitting node is error active or error passive.
Sourcepub const fn brs(&self) -> bool
pub const fn brs(&self) -> bool
Bit Rate Switch. This bit defines whether the bit rate is switched inside a CAN FD format frame.
Sourcepub const fn set_brs(&mut self, val: bool)
pub const fn set_brs(&mut self, val: bool)
Bit Rate Switch. This bit defines whether the bit rate is switched inside a CAN FD format frame.